@@ -72,7 +72,7 @@ class Cloud9Client:
         subnetId: str = None,
         automaticStopTimeMinutes: int = None,
         ownerArn: str = None,
-        tags: List[TagTypeDef] = None,
+        tags: List["TagTypeDef"] = None,
     ) -> CreateEnvironmentEC2ResultTypeDef:
         """
         [Client.create_environment_ec2 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/cloud9.html#Cloud9.Client.create_environment_ec2)
@@ -142,7 +142,7 @@ class Cloud9Client:
         [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/cloud9.html#Cloud9.Client.list_tags_for_resource)
         """
 
-    def tag_resource(self, ResourceARN: str, Tags: List[TagTypeDef]) -> Dict[str, Any]:
+    def tag_resource(self, ResourceARN: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
         [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/cloud9.html#Cloud9.Client.tag_resource)
         """
