@@ -3,9 +3,9 @@ Main interface for cloud9 service type definitions.
 
 Usage::
 
-    from mypy_boto3.cloud9.type_defs import CreateEnvironmentEC2ResultTypeDef
+    from mypy_boto3.cloud9.type_defs import EnvironmentLifecycleTypeDef
 
-    data: CreateEnvironmentEC2ResultTypeDef = {...}
+    data: EnvironmentLifecycleTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,23 +22,29 @@ else:
 
 
 __all__ = (
-    "CreateEnvironmentEC2ResultTypeDef",
+    "EnvironmentLifecycleTypeDef",
     "EnvironmentMemberTypeDef",
+    "EnvironmentTypeDef",
+    "TagTypeDef",
+    "CreateEnvironmentEC2ResultTypeDef",
     "CreateEnvironmentMembershipResultTypeDef",
     "DescribeEnvironmentMembershipsResultTypeDef",
     "DescribeEnvironmentStatusResultTypeDef",
-    "EnvironmentLifecycleTypeDef",
-    "EnvironmentTypeDef",
     "DescribeEnvironmentsResultTypeDef",
     "ListEnvironmentsResultTypeDef",
-    "TagTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "PaginatorConfigTypeDef",
     "UpdateEnvironmentMembershipResultTypeDef",
 )
 
-CreateEnvironmentEC2ResultTypeDef = TypedDict(
-    "CreateEnvironmentEC2ResultTypeDef", {"environmentId": str}, total=False
+EnvironmentLifecycleTypeDef = TypedDict(
+    "EnvironmentLifecycleTypeDef",
+    {
+        "status": Literal["CREATING", "CREATED", "CREATE_FAILED", "DELETING", "DELETE_FAILED"],
+        "reason": str,
+        "failureResource": str,
+    },
+    total=False,
 )
 
 EnvironmentMemberTypeDef = TypedDict(
@@ -53,15 +59,35 @@ EnvironmentMemberTypeDef = TypedDict(
     total=False,
 )
 
+EnvironmentTypeDef = TypedDict(
+    "EnvironmentTypeDef",
+    {
+        "id": str,
+        "name": str,
+        "description": str,
+        "type": Literal["ssh", "ec2"],
+        "arn": str,
+        "ownerArn": str,
+        "lifecycle": "EnvironmentLifecycleTypeDef",
+    },
+    total=False,
+)
+
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
+
+CreateEnvironmentEC2ResultTypeDef = TypedDict(
+    "CreateEnvironmentEC2ResultTypeDef", {"environmentId": str}, total=False
+)
+
 CreateEnvironmentMembershipResultTypeDef = TypedDict(
     "CreateEnvironmentMembershipResultTypeDef",
-    {"membership": EnvironmentMemberTypeDef},
+    {"membership": "EnvironmentMemberTypeDef"},
     total=False,
 )
 
 DescribeEnvironmentMembershipsResultTypeDef = TypedDict(
     "DescribeEnvironmentMembershipsResultTypeDef",
-    {"memberships": List[EnvironmentMemberTypeDef], "nextToken": str},
+    {"memberships": List["EnvironmentMemberTypeDef"], "nextToken": str},
     total=False,
 )
 
@@ -76,42 +102,16 @@ DescribeEnvironmentStatusResultTypeDef = TypedDict(
     total=False,
 )
 
-EnvironmentLifecycleTypeDef = TypedDict(
-    "EnvironmentLifecycleTypeDef",
-    {
-        "status": Literal["CREATING", "CREATED", "CREATE_FAILED", "DELETING", "DELETE_FAILED"],
-        "reason": str,
-        "failureResource": str,
-    },
-    total=False,
-)
-
-EnvironmentTypeDef = TypedDict(
-    "EnvironmentTypeDef",
-    {
-        "id": str,
-        "name": str,
-        "description": str,
-        "type": Literal["ssh", "ec2"],
-        "arn": str,
-        "ownerArn": str,
-        "lifecycle": EnvironmentLifecycleTypeDef,
-    },
-    total=False,
-)
-
 DescribeEnvironmentsResultTypeDef = TypedDict(
-    "DescribeEnvironmentsResultTypeDef", {"environments": List[EnvironmentTypeDef]}, total=False
+    "DescribeEnvironmentsResultTypeDef", {"environments": List["EnvironmentTypeDef"]}, total=False
 )
 
 ListEnvironmentsResultTypeDef = TypedDict(
     "ListEnvironmentsResultTypeDef", {"nextToken": str, "environmentIds": List[str]}, total=False
 )
 
-TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
-
 ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef", {"Tags": List[TagTypeDef]}, total=False
+    "ListTagsForResourceResponseTypeDef", {"Tags": List["TagTypeDef"]}, total=False
 )
 
 PaginatorConfigTypeDef = TypedDict(
@@ -120,6 +120,6 @@ PaginatorConfigTypeDef = TypedDict(
 
 UpdateEnvironmentMembershipResultTypeDef = TypedDict(
     "UpdateEnvironmentMembershipResultTypeDef",
-    {"membership": EnvironmentMemberTypeDef},
+    {"membership": "EnvironmentMemberTypeDef"},
     total=False,
 )
